@@ -12,7 +12,7 @@ import uuid
 
 import GPUtil
 
-from imjoy import __version__, API_VERSION, HERE
+from imjoy import __version__, API_VERSION, IMJOY_PACKAGE_DIR
 from imjoy.connection.decorator import socketio_handler as sio_on
 from imjoy.utils import console_to_str, parse_repos, get_psutil, kill_process
 from .helper import (
@@ -24,10 +24,6 @@ from .helper import (
     run_process,
 )
 
-DEFAULT_REQUIREMENTS_PY2 = ["numpy", "python-socketio[client]"]
-DEFAULT_REQUIREMENTS_PY3 = ["numpy", "python-socketio[client]", "janus"]
-REQ_PSUTIL = ["psutil"]
-REQ_PSUTIL_CONDA = ["conda:psutil"]
 MAX_ATTEMPTS = 1000
 
 
@@ -68,10 +64,19 @@ async def on_init_plugin(engine, sid, kwargs):
             os.makedirs(work_dir)
         plugin_env = os.environ.copy()
         plugin_env["WORK_DIR"] = work_dir
-        imjoy_path = str(HERE.resolve())
-        plugin_env["PYTHONPATH"] = (
-            imjoy_path + os.path.pathsep + plugin_env.get("PYTHONPATH", "")
-        )
+        if engine.opt.dev:
+            plugin_env["PYTHONPATH"] = (
+                IMJOY_PACKAGE_DIR + os.path.pathsep + plugin_env.get("PYTHONPATH", "")
+            )
+            worker_module = "workers.python_worker"
+            logger.debug(
+                "ImJoy package directory was added to PYTHONPATH, will run module `workers.python_worker`."
+            )
+        else:
+            worker_module = "imjoy.workers.python_worker"
+            logger.debug(
+                "Will run module `imjoy.workers.python_worker` from installed ImJoy package."
+            )
 
         logger.info(
             "Initialize the plugin, name=%s, id=%s, cmd=%s, workspace=%s",
@@ -191,8 +196,8 @@ async def on_init_plugin(engine, sid, kwargs):
             )
             asyncio.run_coroutine_threadsafe(coro, eloop).result()
 
-        args = '{} -m workers.python_worker --id="{}" --server={} --secret="{}"'.format(
-            cmd, pid, "http://127.0.0.1:" + engine.opt.port, secret_key
+        args = '{} -m {} --id="{}" --server={} --secret="{}"'.format(
+            cmd, worker_module, pid, "http://127.0.0.1:" + engine.opt.port, secret_key
         )
         task_thread = threading.Thread(
             target=launch_plugin,
@@ -242,7 +247,8 @@ async def on_register_client(engine, sid, kwargs):
 
     token = kwargs.get("token")
     if token != engine.opt.token:
-        logger.debug("Token mismatch: %s != %s", token, engine.opt.token)
+        logger.error("Wrong connection token (%s)", token)
+        print("========>> Connection token: {} <<========".format(engine.opt.token))
         if engine.opt.engine_container_token is not None:
             await engine.conn.sio.emit(
                 "message_to_container_" + engine.opt.engine_container_token,
@@ -265,7 +271,7 @@ async def on_register_client(engine, sid, kwargs):
                 conn_data.attempt_count,
             )
             sys.exit(100)
-        return {"success": False}
+        return {"success": False, "message": "Connection token mismatch."}
 
     conn_data.attempt_count = 0
     if add_client_session(engine, session_id, client_id, sid, base_url, workspace):
@@ -631,9 +637,11 @@ def launch_plugin(
         default_virtual_env = default_virtual_env.replace(" ", "_")
         venv_name, envs, is_py2 = parse_env(engine, env, work_dir, default_virtual_env)
         environment_variables = {}
-        default_requirements = (
-            DEFAULT_REQUIREMENTS_PY2 if is_py2 else DEFAULT_REQUIREMENTS_PY3
-        )
+
+        if engine.opt.dev:
+            default_requirements = ["imjoy[worker]"]
+        else:
+            default_requirements = ["imjoy[worker]==" + __version__]
         default_reqs_cmds = parse_requirements(
             default_requirements, conda=opt.conda_available
         )
@@ -653,7 +661,7 @@ def launch_plugin(
             """Notify when an install process command has finished."""
             logger.debug("Finished running (pid=%s): %s", pid, cmd)
             nonlocal progress
-            progress += int(70 / (len(envs) + len(reqs_cmds) + len(REQ_PSUTIL)))
+            progress += int(70 / (len(envs) + len(reqs_cmds)))
             logging_callback(progress, type="progress")
 
         for _env in envs:
@@ -721,25 +729,6 @@ def launch_plugin(
             logging_callback,
         )
 
-        if not opt.freeze:
-            psutil_cmds = parse_requirements(REQ_PSUTIL)
-            logger.info("Running requirements commands: %s", psutil_cmds)
-            code, _ = run_commands(
-                plugin_env, work_dir, psutil_cmds, process_start, process_finish
-            )
-        if not opt.freeze and code and opt.conda_available and venv_name is not None:
-            logger.info("Failed installing psutil with pip, trying conda")
-            psutil_cmds = parse_requirements(
-                REQ_PSUTIL_CONDA, conda=opt.conda_available
-            )
-            psutil_cmds = apply_conda_activate(
-                psutil_cmds, opt.conda_activate, venv_name
-            )
-            logger.info("Running requirements commands: %s", psutil_cmds)
-            code, _ = run_commands(
-                plugin_env, work_dir, psutil_cmds, process_start, process_finish
-            )
-
     except Exception:  # pylint: disable=broad-except
         error_traceback = traceback.format_exc()
         logger.error(
